pub struct Stats {
pub enabled: bool,
pub incomplete: bool,
pub total_bytes: u64,
pub total_blocks: u64,
pub live_bytes: u64,
pub live_blocks: u64,
pub peak_bytes: u64,
pub peak_blocks: u64,
pub dropped: u64,
pub internal_bytes: u64,
}Expand description
Snapshot of exact DHAT collector state.
Fields
enabled: boolincomplete: boolTrue when raw-OS collector storage hit its configured budget or an internal allocation failed. The application allocation still completed, but the resulting profile is intentionally marked partial.
total_bytes: u64total_blocks: u64live_bytes: u64live_blocks: u64peak_bytes: u64peak_blocks: u64dropped: u64internal_bytes: u64Trait Implementations
impl Eq for Stats
impl StructuralPartialEq for Stats