usable_size

Function usable_size 

pub unsafe fn usable_size(p: *const u8) -> usize
Bytes actually available in an allocation, which may exceed what was requested.

Safety

p must be a live pointer from this allocator.