pub fn dump_proto_file(path: &Path) -> Result<()>Expand description
Write the current heap profile to path in profile.proto format.
See dump_proto_to_vec for the format details.
pub fn dump_proto_file(path: &Path) -> Result<()>Write the current heap profile to path in profile.proto format.
See dump_proto_to_vec for the format details.