pub fn bin_size(bin: usize) -> usizeExpand description
The block size served by size bin bin (0..=sys::MI_BIN_HUGE), matching the
malloc_bins/page_bins indices.
pub fn bin_size(bin: usize) -> usizeThe block size served by size bin bin (0..=sys::MI_BIN_HUGE), matching the
malloc_bins/page_bins indices.