pub unsafe extern "C" fn mi_stats_get(stats: *mut mi_stats_t) -> boolExpand description
Mirrors mi_stats_get: aggregated stats for the current subprocess and its heaps.
pub unsafe extern "C" fn mi_stats_get(stats: *mut mi_stats_t) -> boolMirrors mi_stats_get: aggregated stats for the current subprocess and its heaps.